"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gcpLogOptions = void 0;
const crypto_1 = require("crypto");
const levelToSeverity = {
    trace: 'DEBUG',
    debug: 'DEBUG',
    info: 'INFO',
    warn: 'WARNING',
    error: 'ERROR',
    fatal: 'CRITICAL',
};
function gcpLogOptions(config) {
    return {
        formatters: {
            level(label) {
                const severity = levelToSeverity[label] ?? 'INFO';
                const logObject = { severity };
                const pinoLevel = label;
                if (pinoLevel === 'error' || pinoLevel === 'fatal') {
                    logObject['@type'] =
                        'type.googleapis.com/google.devtools.clouderrorreporting.v1beta1.ReportedErrorEvent';
                }
                return logObject;
            },
            log(object) {
                const logObject = {
                    insertId: (0, crypto_1.randomUUID)(),
                };
                if (object?.error?.stack) {
                    logObject.stack_trace = logObject.error.stack;
                }
                if (object?.err?.stack) {
                    logObject.stack_trace = logObject.err.stack;
                }
                return logObject;
            },
        },
        messageKey: 'message',
        ...config,
    };
}
exports.gcpLogOptions = gcpLogOptions;
//# sourceMappingURL=pino-config.js.map